==> CrystalDiskMark4_1_0Src.zip: CrystalDiskMark/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ ŐꂽCN[h t@CB
// DiskMark.rc Ŏgp
//
#define IDD_DISKMARK_DIALOG             102
#define IDR_HTML_ABOUTDLG               103
#define IDR_HTML_DISKMARK_DIALOG        104
#define IDR_HTML_DUMMY                  105
#define IDR_MENU                        129
#define IDR_MAINFRAME                   130
#define IDD_ABOUT                       131
#define IDR_PNG1                        134
#define IDR_PNG2                        135
#define IDR_ACCELERATOR                 136
#define IDI_ICON1                       138
#define IDI_TRAY_ICON                   138
#define IDD_SETTINGS                    139
#define IDC_BUTTON1                     1002
#define ID_FILE_EXIT                    32771
#define ID_HELP_ABOUT                   32772
#define ID_THEME                        32775
#define ID_THEME_DUMMY                  32776
#define ID_EDIT_COPY_TEXT               32777
#define ID_LANGUAGE_DUMMY               32778
#define ID_LANGUAGE_A                   32779
#define ID_LANGUAGE_O                   32780
#define ID_A_DUMMY                      32781
#define ID_O_DUMMY                      32782
#define ID_BACK_PAGE                    32787
#define ID_PRINT                        32790
#define ID_FUNCTION_ZOOM                32800
#define ID_ZOOM_100                     32801
#define ID_ZOOM_125                     32802
#define ID_ZOOM_150                     32803
#define ID_ZOOM_200                     32804
#define ID_ZOOM_250                     32805
#define ID_ZOOM_300                     32806
#define ID_ZOOM_400                     32807
#define ID_ZOOM_AUTO                    33808
#define ID_IE8_MODE                     33809
#define ID_HELP_HELP                    32810
#define ID_HELP_CRYSTALDEWWORLD         32811
#define ID_FILE_BENCHMARKMODE           32812
#define ID_MODE_DEFAULT                 32815
#define ID_MODE_ALL0X00                 32816
#define ID_MODE_ALL0XFF                 32817
#define ID_SETTINGS_QUEUESTHREADS       32818
#define ID_RESULT_SAVE                  32819

#define ID_INTERVAL_TIME_0              33820
#define ID_INTERVAL_TIME_1              33821
#define ID_INTERVAL_TIME_3              33822
#define ID_INTERVAL_TIME_5              33823
#define ID_INTERVAL_TIME_10             33824
#define ID_INTERVAL_TIME_30             33825
#define ID_INTERVAL_TIME_60             33826
#define ID_INTERVAL_TIME_180            33827
#define ID_INTERVAL_TIME_300            33828
#define ID_INTERVAL_TIME_600            33829

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        140
#define _APS_NEXT_COMMAND_VALUE         33809
#define _APS_NEXT_CONTROL_VALUE         1003
#define _APS_NEXT_SYMED_VALUE           107
#endif
#endif

==> CrystalDiskMark5_1_2Src.zip: CrystalDiskMark/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ ŐꂽCN[h t@CB
// DiskMark.rc Ŏgp
//
#define IDD_DISKMARK_DIALOG             102
#define IDR_HTML_ABOUTDLG               103
#define IDR_HTML_DISKMARK_DIALOG        104
#define IDR_HTML_DUMMY                  105
#define IDR_MENU                        129
#define IDR_MAINFRAME                   130
#define IDD_ABOUT                       131
#define IDR_PNG1                        134
#define IDR_PNG2                        135
#define IDR_ACCELERATOR                 136
#define IDI_ICON1                       138
#define IDI_TRAY_ICON                   138
#define IDD_SETTINGS                    139
#define IDC_BUTTON1                     1002
#define ID_FILE_EXIT                    32771
#define ID_HELP_ABOUT                   32772
#define ID_THEME                        32775
#define ID_THEME_DUMMY                  32776
#define ID_EDIT_COPY_TEXT               32777
#define ID_LANGUAGE_DUMMY               32778
#define ID_LANGUAGE_A                   32779
#define ID_LANGUAGE_O                   32780
#define ID_A_DUMMY                      32781
#define ID_O_DUMMY                      32782
#define ID_BACK_PAGE                    32787
#define ID_PRINT                        32790
#define ID_FUNCTION_ZOOM                32799
#define ID_ZOOM_75                      32800
#define ID_ZOOM_100                     32801
#define ID_ZOOM_125                     32802
#define ID_ZOOM_150                     32803
#define ID_ZOOM_200                     32804
#define ID_ZOOM_250                     32805
#define ID_ZOOM_300                     32806
#define ID_ZOOM_400                     32807
#define ID_ZOOM_AUTO                    33808
#define ID_IE8_MODE                     33809
#define ID_HELP_HELP                    32810
#define ID_HELP_CRYSTALDEWWORLD         32811
#define ID_FILE_BENCHMARKMODE           32812
#define ID_MODE_DEFAULT                 32815
#define ID_MODE_ALL0X00                 32816
#define ID_MODE_ALL0XFF                 32817
#define ID_SETTINGS_QUEUESTHREADS       32818
#define ID_RESULT_SAVE                  32819

#define ID_INTERVAL_TIME_0              33820
#define ID_INTERVAL_TIME_1              33821
#define ID_INTERVAL_TIME_3              33822
#define ID_INTERVAL_TIME_5              33823
#define ID_INTERVAL_TIME_10             33824
#define ID_INTERVAL_TIME_30             33825
#define ID_INTERVAL_TIME_60             33826
#define ID_INTERVAL_TIME_180            33827
#define ID_INTERVAL_TIME_300            33828
#define ID_INTERVAL_TIME_600            33829

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        140
#define _APS_NEXT_COMMAND_VALUE         33809
#define _APS_NEXT_CONTROL_VALUE         1003
#define _APS_NEXT_SYMED_VALUE           107
#endif
#endif
